@@ -5,7 +5,6 @@ from maleo.soma.enums.operation import ResourceOperationStatusUpdateType
 from maleo.soma.enums.status import DataStatus
 from maleo.soma.types.base import (
     ListOfDataStatuses,
-    SequenceOfDataStatuses,
     SequenceOfStrings,
 )
 
@@ -56,15 +55,15 @@ STATUS_UPDATE_CRITERIAS: Mapping[
         DataStatus.INACTIVE,
     ],
 }
-ALL_STATUSES: SequenceOfDataStatuses = (
+ALL_STATUSES: ListOfDataStatuses = [
     DataStatus.ACTIVE,
     DataStatus.INACTIVE,
     DataStatus.DELETED,
-)
-VISIBLE_STATUSES: SequenceOfDataStatuses = (
+]
+VISIBLE_STATUSES: ListOfDataStatuses = [
     DataStatus.ACTIVE,
     DataStatus.INACTIVE,
-)
+]
 
 # Token
 ACCESS_TOKEN_DURATION_MINUTES: int = 5
