@@ -3,14 +3,14 @@ from maleo.soma.mixins.parameter import (
     IdentifierTypeT,
     IdentifierValueT,
     IdentifierTypeValue,
-    OptionalListOfDataStatuses,
+    ListOfDataStatuses,
     UseCache,
 )
 
 
 class ReadSingleQueryParameterSchema(
     UseCache,
-    OptionalListOfDataStatuses,
+    ListOfDataStatuses,
 ):
     pass
 
